@@ -8,13 +8,12 @@ package constants
 import (
 	"time"
 
-	cni "github.com/containerd/go-cni"
 	"github.com/siderolabs/crypto/x509"
 )
 
 const (
 	// DefaultKernelVersion is the default Linux kernel version.
-	DefaultKernelVersion = "6.16.9-talos"
+	DefaultKernelVersion = "6.18.8-talos"
 
 	// KernelParamConfig is the kernel parameter name for specifying the URL.
 	// to the config.
@@ -58,10 +57,6 @@ const (
 	// platform.
 	KernelParamPlatform = "talos.platform"
 
-	// KernelParamBoard is the kernel parameter name for specifying the
-	// SBC.
-	KernelParamBoard = "talos.board"
-
 	// KernelParamEventsSink is the kernel parameter name for specifying the
 	// events sink server.
 	KernelParamEventsSink = "talos.events.sink"
@@ -87,6 +82,9 @@ const (
 	// KernelParamDashboardDisabled is the kernel parameter name for disabling the dashboard.
 	KernelParamDashboardDisabled = "talos.dashboard.disabled"
 
+	// KernelParamDashboardConsole is the kernel parameter name for specifying the dashboard console.
+	KernelParamDashboardConsole = "talos.dashboard.console"
+
 	// KernelParamEnvironment is the kernel parameter name for passing process environment.
 	KernelParamEnvironment = "talos.environment"
 
@@ -102,36 +100,6 @@ const (
 	// KernelParamSELinuxEnforcing is the kernel parameter name to control SELinux enforcement mode.
 	KernelParamSELinuxEnforcing = "enforcing"
 
-	// BoardNone indicates that the install is not for a specific board.
-	BoardNone = "none"
-
-	// BoardLibretechAllH3CCH5 is the  name of the Libre Computer board ALL-H3-CC.
-	BoardLibretechAllH3CCH5 = "libretech_all_h3_cc_h5"
-
-	// BoardRPiGeneric is the  name of the Raspberry Pi Compute Module 4.
-	BoardRPiGeneric = "rpi_generic"
-
-	// BoardBananaPiM64 is the  name of the Banana Pi M64.
-	BoardBananaPiM64 = "bananapi_m64"
-
-	// BoardPine64 is the  name of the Pine64.
-	BoardPine64 = "pine64"
-
-	// BoardJetsonNano is the name of the Jetson Nano.
-	BoardJetsonNano = "jetson_nano"
-
-	// BoardRock64 is the  name of the Rock64.
-	BoardRock64 = "rock64"
-
-	// BoardRockpi4 is the name of the Radxa Rock pi 4 revisions A and B.
-	BoardRockpi4 = "rockpi_4"
-
-	// BoardRockpi4c is the name of the Radxa Rock pi 4 revision C.
-	BoardRockpi4c = "rockpi_4c"
-
-	// BoardNanoPiR4S is the name of the Friendlyelec Nano Pi R4S.
-	BoardNanoPiR4S = "nanopi_r4s"
-
 	// KernelParamHostname is the kernel parameter name for specifying the
 	// hostname.
 	KernelParamHostname = "talos.hostname"
@@ -159,6 +127,10 @@ const (
 	// This param is injected by Equinix Metal and depends on the device ID and datacenter.
 	KernelParamEquinixMetalEvents = "em.events_url"
 
+	// KernelParamEnforceModuleSigVerify is the kernel parameter name to specify module signature verification enforcement.
+	// see https://github.com/siderolabs/talos/issues/11989
+	KernelParamEnforceModuleSigVerify = "module.sig_enforce"
+
 	// NewRoot is the path where the switchroot target is mounted.
 	NewRoot = "/root"
 
@@ -230,9 +202,6 @@ const (
 	// installer.
 	ISOFilesystemLabel = "TALOS"
 
-	// PATH defines all locations where executables are stored.
-	PATH = "/usr/bin:/usr/local/sbin:/usr/local/bin:" + cni.DefaultCNIDir
-
 	// KubernetesDefaultCertificateValidityDuration specifies default certificate duration for Kubernetes generated certificates.
 	KubernetesDefaultCertificateValidityDuration = time.Hour * 24 * 365
 
@@ -394,7 +363,7 @@ const (
 
 	// DefaultKubernetesVersion is the default target version of the control plane.
 	// renovate: datasource=github-releases depName=kubernetes/kubernetes
-	DefaultKubernetesVersion = "1.34.1"
+	DefaultKubernetesVersion = "1.35.0"
 
 	// SupportedKubernetesVersions is the number of Kubernetes versions supported by Talos starting from DefaultKubernesVersion going backwards.
 	SupportedKubernetesVersions = 6
@@ -422,7 +391,7 @@ const (
 
 	// DefaultCoreDNSVersion is the default version for the CoreDNS.
 	// renovate: datasource=docker depName=registry.k8s.io/coredns/coredns
-	DefaultCoreDNSVersion = "v1.12.4"
+	DefaultCoreDNSVersion = "v1.13.2"
 
 	// LabelNodeRoleControlPlane is the node label required by a control plane node.
 	LabelNodeRoleControlPlane = "node-role.kubernetes.io/control-plane"
@@ -455,8 +424,8 @@ const (
 	KubeletSystemReservedEphemeralStorage = "256Mi"
 
 	// DefaultEtcdVersion is the default target version of etcd.
-	// renovate: datasource=github-releases depName=etcd-io/etcd
-	DefaultEtcdVersion = "v3.6.5"
+	// renovate: datasource=docker depName=registry.k8s.io/etcd
+	DefaultEtcdVersion = "v3.6.7"
 
 	// EtcdRootTalosKey is the root etcd key for Talos-specific storage.
 	EtcdRootTalosKey = "talos:v1"
@@ -471,7 +440,7 @@ const (
 	EtcdTalosServiceAccountCRDControllerMutex = EtcdRootTalosKey + ":serviceAccountCRDController"
 
 	// EtcdImage is the reposistory for the etcd image.
-	EtcdImage = "gcr.io/etcd-development/etcd"
+	EtcdImage = "registry.k8s.io/etcd"
 
 	// EtcdPKIPath is the path to the etcd PKI directory.
 	EtcdPKIPath = "/system/secrets/etcd"
@@ -554,10 +523,10 @@ const (
 	TrustdUserID = 51
 
 	// DefaultContainerdVersion is the default container runtime version.
-	DefaultContainerdVersion = "2.1.4"
+	DefaultContainerdVersion = "2.2.1"
 
 	// RuncVersion is the runc version.
-	RuncVersion = "1.3.1"
+	RuncVersion = "1.4.0"
 
 	// SystemContainerdNamespace is the Containerd namespace for Talos services.
 	SystemContainerdNamespace = "system"
@@ -595,6 +564,9 @@ const (
 	// TalosConfigEnvVar is the environment variable for setting the Talos configuration file path.
 	TalosConfigEnvVar = "TALOSCONFIG"
 
+	// TalosHomeEnvVar is the environment variable for setting the Talos state directory file path.
+	TalosHomeEnvVar = "TALOS_HOME"
+
 	// APISocketPath is the path to file socket of apid.
 	APISocketPath = SystemRunPath + "/apid/apid.sock"
 
@@ -664,15 +636,6 @@ const (
 	// SDBootAssetPath is the path to the SDBoot in the installer.
 	SDBootAssetPath = "/usr/install/%s/" + SDBootAsset
 
-	// DTBAssetPath is the path to the device tree blobs in the installer.
-	DTBAssetPath = "/usr/install/%s/dtb"
-
-	// UBootAssetPath is the path to the u-boot in the installer.
-	UBootAssetPath = "/usr/install/%s/u-boot"
-
-	// RPiFirmwareAssetPath is the path to the raspberrypi firmware in the installer.
-	RPiFirmwareAssetPath = "/usr/install/%s/raspberrypi-firmware"
-
 	// ImagerOverlayBasePath is the base path for the imager overlay.
 	ImagerOverlayBasePath = "/overlay"
 	// ImagerOverlayArtifactsPath is the path to the artifacts in the imager overlay.
@@ -1118,7 +1081,7 @@ const (
 	DBusClientSocketLabel = "system_u:object_r:dbus_client_socket_t:s0"
 
 	// GoVersion is the version of Go compiler this release was built with.
-	GoVersion = "go1.25.1"
+	GoVersion = "go1.25.6"
 
 	// KubernetesTalosAPIServiceName is the name of the Kubernetes service to access Talos API.
 	KubernetesTalosAPIServiceName = "talos"
@@ -1135,6 +1098,15 @@ const (
 	// KubernetesTalosProvider is the name of the Talos provider as a Kubernetes label.
 	KubernetesTalosProvider = "talos.dev"
 
+	// KubernetesInventoryNamespace is the namespace where Talos inventory objects are stored.
+	KubernetesInventoryNamespace = "kube-system"
+
+	// KubernetesBootstrapManifestsInventoryName is the name of the Talos bootstrap manifests inventory object.
+	KubernetesBootstrapManifestsInventoryName = "talos-bootstrap-manifests-inventory"
+
+	// KubernetesFieldManagerName is the field manager name used by Talos when applying manifests.
+	KubernetesFieldManagerName = "talos"
+
 	// ServiceAccountResourceGroup is the group name of the Talos service account CRD.
 	ServiceAccountResourceGroup = "talos.dev"
 
@@ -1184,7 +1156,12 @@ const (
 	DashboardTTY = 2
 
 	// FlannelVersion is the version of flannel to use.
-	FlannelVersion = "v0.27.2"
+	//
+	// Note: while updating, make sure to copy flannel image from docker.io to ghcr.io:
+	//   crane cp docker.io/flannel/flannel:vX.Y.Z ghcr.io/siderolabs/flannel:vX.Y.Z
+	//
+	// renovate: datasource=github-releases depName=flannel-io/flannel
+	FlannelVersion = "v0.27.4"
 
 	// PlatformMetal is the name of the metal platform.
 	PlatformMetal = "metal"
@@ -1198,9 +1175,6 @@ const (
 	// GRPCMaxMessageSize is the maximum message size for Talos API.
 	GRPCMaxMessageSize = 32 * 1024 * 1024
 
-	// TcellMinimizeEnvironment is the environment variable to minimize tcell library memory usage (skips rune width calculation).
-	TcellMinimizeEnvironment = "TCELL_MINIMIZE=1"
-
 	// DefaultKubePrismPort is the default port for the KubePrism loadbalancer.
 	DefaultKubePrismPort = 7445
 
@@ -1263,9 +1237,15 @@ const (
 	// UserVolumeMountPoint is the path to the volume mount point for the user volumes.
 	UserVolumeMountPoint = "/var/mnt"
 
+	// LogMountPoint is the path to the logs mount point, and ID of the logs volume.
+	LogMountPoint = "/var/log"
+
 	// UserVolumePrefix is the prefix for the user volumes.
 	UserVolumePrefix = "u-"
 
+	// ExternalVolumePrefix is the prefix for the user volumes.
+	ExternalVolumePrefix = "x-"
+
 	// RawVolumePrefix is the prefix for the raw volumes.
 	RawVolumePrefix = "r-"
 
@@ -1302,25 +1282,26 @@ const (
 	ContainerMarkerFilePath = "/usr/etc/in-container"
 
 	// DefaultOOMTriggerExpression is the default CEL expression used to determine whether to trigger OOM.
-	DefaultOOMTriggerExpression = `memory_full_avg10 > 12.0 && time_since_trigger > duration("500ms")`
+	DefaultOOMTriggerExpression = `(multiply_qos_vectors(d_qos_memory_full_total, {System: 8.0, Podruntime: 4.0}) > 3000.0 &&
+	     multiply_qos_vectors(qos_memory_full_avg10, {System: 1.0, Podruntime: 1.0}) > 5.0) ||
+		(memory_full_avg10 > 75.0 && time_since_trigger > duration("10s"))`
 
 	// DefaultOOMCgroupRankingExpression is the default CEL expression used to rank cgroups for OOM killer.
 	DefaultOOMCgroupRankingExpression = `memory_max.hasValue() ? 0.0 :
 		{Besteffort: 1.0, Burstable: 0.5, Guaranteed: 0.0, Podruntime: 0.0, System: 0.0}[class] *
-		   double(memory_current.orValue(0u)) / double(memory_peak.orValue(0u) - memory_current.orValue(0u))`
-)
+		   double(memory_current.orValue(0u))`
 
-// See https://linux.die.net/man/3/klogctl
-//
-//nolint:stylecheck,revive
-const (
-	// SYSLOG_ACTION_SIZE_BUFFER is a named type argument to klogctl.
-	//nolint:golint
-	SYSLOG_ACTION_SIZE_BUFFER = 10
+	// OOMActionLogKeep is the number of OOM action log entries to keep in memory.
+	OOMActionLogKeep = 50
 
-	// SYSLOG_ACTION_READ_ALL is a named type argument to klogctl.
-	//nolint:golint
-	SYSLOG_ACTION_READ_ALL = 3
+	// SDStubCmdlineExtraOEMVar is the name of the SMBIOS OEM variable that can be used to pass extra kernel command line parameters to systemd-stub.
+	SDStubCmdlineExtraOEMVar = "io.systemd.stub.kernel-cmdline-extra"
+
+	// LogRotateThreshold is the size (in bytes), upon exceeding which the log file should be rotated.
+	LogRotateThreshold = 5 * 1024 * 1024
+
+	// LogFlushPeriod is the period for flushing in-memory log buffers to the filesystem.
+	LogFlushPeriod = 15 * time.Second
 )
 
 // names of variable that can be substituted in the talos.config kernel parameter.
